---
sidebar_label: dictionary
title: soil.dictionary
---

This package contains calls for soil get dictionary

#### dictionary

```python
def dictionary(name: str,
               language: str,
               content: Optional[Dict[str, str]] = None) -> Dict[str, Any]
```

Create or get a dictionary

